Pinax Pages
============

.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/
   
.. image:: https://img.shields.io/travis/pinax/pinax-pages.svg
    :target: https://travis-ci.org/pinax/pinax-pages

.. image:: https://img.shields.io/coveralls/pinax/pinax-pages.svg
    :target: https://coveralls.io/r/pinax/pinax-pages

.. image:: https://img.shields.io/pypi/dm/pinax-pages.svg
    :target:  https://pypi.python.org/pypi/pinax-pages/

.. image:: https://img.shields.io/pypi/v/pinax-pages.svg
    :target:  https://pypi.python.org/pypi/pinax-pages/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/pinax-pages/
    
    
Pinax
-------
Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates.
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.

pinax-pages
------------

pinax-pages is a lightweight CMS born out of Symposion.


Running the Tests
------------------------------------

::

    $ pip install detox
    $ detox
    

Documentation
--------------

The Pinax documentation is available at http://pinaxproject.com/pinax/.


Code of Conduct
-----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a Code of Conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
-------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at [@pinaxproject](https://twitter.com/pinaxproject) and check out our blog http://blog.pinaxproject.com.
